import React, { useState } from 'react';
import { Button, message } from 'antd';
import { ModalForm, ProFormSelect, ProFormText } from '@ant-design/pro-components';
import { PlusOutlined } from '@ant-design/icons';
import { FormattedMessage } from '@@/plugin-locale';
import { createCamera } from '@/services/api/camera';

const handleAdd = async (fields: API.CameraCreateDto) => {
  const hide = message.loading('正在添加');
  try {
    const { status_code, message: msg } = await createCamera({ ...fields });
    if (status_code === 200) {
      hide();
      message.success(msg);
      return true;
    }
    message.error(msg);
    return false;
  } catch (error) {
    hide();
    return false;
  }
};

type AddCameraViewProps = {
  onSubmit: () => void;
};

const AddCamera: React.FC<AddCameraViewProps> = (props) => {
  const { onSubmit } = props;
  const [modalVisible, handleModalVisible] = useState<boolean>(false);
  return (
    <>
      <Button
        type="primary"
        key="primary"
        onClick={() => {
          handleModalVisible(true);
        }}
      >
        <PlusOutlined /> <FormattedMessage id="pages.searchTable.new" defaultMessage="New" />
      </Button>
      <ModalForm
        isKeyPressSubmit={false}
        title={'新建用户'}
        width="400px"
        open={modalVisible}
        onOpenChange={() => {
          handleModalVisible(false);
        }}
        onFinish={async (value) => {
          const success = await handleAdd(value as API.CameraCreateDto);
          if (success) {
            onSubmit();
            handleModalVisible(false);
          }
        }}
      >
        <ProFormText
          label="标题"
          name="title"
          rules={[
            {
              required: true,
              message: '标题为必填项',
            },
          ]}
        />
        <ProFormText
          label="拉流URL"
          name="pull_url"
          rules={[
            {
              required: true,
              message: '拉流URL为必填项',
            },
          ]}
        />
        <ProFormText label="推流URL" name="push_url" />
        <ProFormSelect
          label="预测模型"
          name="model"
          request={async () => [{ label: '暴力检测', value: 'violent_detection' }]}
          rules={[
            {
              required: true,
              message: '预测模型为必选项',
            },
          ]}
        />
      </ModalForm>
    </>
  );
};
export default AddCamera;
