import React, { useEffect, useState } from 'react';
import { Card, Form, message, Spin } from 'antd';
import { ProForm, ProFormRadio, ProFormSelect, ProFormText } from '@ant-design/pro-components';
import { updateUserDetails, getUsersById } from '@/services/api/user';
import EditUserPassword from './editPassword';

const handleEdit = async (user_id: number, fields: API.UserUpdateDetailsDto) => {
  const hide = message.loading('正在修改');
  try {
    const { status_code, message: msg } = await updateUserDetails({ user_id }, { ...fields });
    if (status_code === 200) {
      hide();
      message.success(msg);
      return true;
    }
    message.error(msg);
    return false;
  } catch (error) {
    hide();
    message.error('Adding failed, please try again!');
    return false;
  }
};

type EditUserViewProps = {
  title: string;
  user_id: number;
};

const EditUser: React.FC<EditUserViewProps> = (props) => {
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(true);

  const { title, user_id } = props;

  const handleRefresh = () => {
    setLoading(true);
    getUsersById({ user_id }).then(({ status_code, data }) => {
      if (status_code === 200) {
        form.setFieldsValue(data);
        setLoading(false);
      }
    });
  };

  useEffect(() => {
    handleRefresh();
  }, [form, user_id]);

  return (
    <Spin spinning={loading}>
      <Card>
        <ProForm
          form={form}
          isKeyPressSubmit={false}
          title={title}
          onFinish={async (value) => {
            setLoading(true);
            const success = await handleEdit(user_id, value as API.UserUpdateDetailsDto);
            if (success) {
            }
            setLoading(false);
          }}
          onReset={() => {
            handleRefresh();
          }}
        >
          <ProFormText
            label="用户名"
            name="username"
            rules={[
              {
                required: true,
                message: '账号为必填项',
              },
            ]}
          />
          <ProFormSelect
            name="role"
            label="权限"
            initialValue="ROLE_GUEST"
            valueEnum={{
              ROLE_GUEST: '普通用户',
              ROLE_ADMIN: '超级用户',
            }}
            rules={[
              {
                required: true,
                message: '权限为必选项',
              },
            ]}
          />
          <ProFormRadio.Group
            name="status"
            label="状态"
            options={[
              {
                label: '启用',
                value: 1,
              },
              {
                label: '禁用',
                value: 2,
              },
            ]}
          />
          <ProForm.Item label="密码">
            <EditUserPassword user_id={user_id} onSubmit={() => {}} />
          </ProForm.Item>
        </ProForm>
      </Card>
    </Spin>
  );
};
export default EditUser;
