declare namespace API {
  type AuthResponseDto = {
    /** user_id */
    user_id: number;
    /** 令牌 */
    token: string;
    /** 资源令牌 */
    resource_token: string;
    /** 刷新令牌 */
    refresh_token: string;
    /** 创建时间 */
    create_time: number;
    /** 更新时间 */
    update_time: number;
    /** 删除时间 */
    delete_time: number;
  };

  type CameraCreateDto = {
    /** 标题 */
    title: string;
    /** 拉流URL */
    pull_url: string;
    /** 推流URL */
    push_url: string;
    /** 使用的模型 */
    model: string;
  };

  type CameraResponseDto = {
    /** camera_id */
    camera_id: number;
    /** 标题 */
    title: string;
    /** 拉流URL */
    pull_url: string;
    /** 推流URL */
    push_url: string;
    /** 使用的模型 */
    model: string;
    /** 状态 */
    status: number;
    /** 创建时间 */
    create_time: number;
    /** 更新时间 */
    update_time: number;
    /** 删除时间 */
    delete_time: number;
  };

  type CameraUpdateDetailsDto = {
    /** 标题 */
    title: string;
    /** 拉流URL */
    pull_url: string;
    /** 推流URL */
    push_url: string;
    /** 检测模型 */
    model: string;
    /** 状态 */
    status: number;
  };

  type CameraUpdateStatusDto = {
    /** 状态 */
    status: number;
  };

  type getCameraByIdParams = {
    camera_id: number;
  };

  type getCamerasParams = {
    page: number;
    page_size: number;
    keyWords?: string;
    model?: string;
    status?: number;
  };

  type getUsersByIdParams = {
    user_id: number;
  };

  type getUsersParams = {
    page: number;
    page_size: number;
    keyWords?: string;
    username?: string;
    role?: string;
    status?: number;
  };

  type MessageDto = {
    /** 状态代码 */
    status_code: number;
    /** 简短的状态文本; OK 或者 ERROR */
    status: string;
    /** 详细的信息 */
    message: string;
    /** 返回数据 */
    data: any;
  };

  type MessageDtoComposeAuthDto = {
    /** 状态代码 */
    status_code: number;
    /** 简短的状态文本; OK 或者 ERROR */
    status: string;
    /** 详细的信息 */
    message: string;
    /** 返回数据 */
    data: AuthResponseDto;
  };

  type MessageDtoComposeCameraResponseDto = {
    /** 状态代码 */
    status_code: number;
    /** 简短的状态文本; OK 或者 ERROR */
    status: string;
    /** 详细的信息 */
    message: string;
    /** 返回数据 */
    data: CameraResponseDto;
  };

  type MessageDtoComposePageOfCameras = {
    /** 状态代码 */
    status_code: number;
    /** 简短的状态文本; OK 或者 ERROR */
    status: string;
    /** 详细的信息 */
    message: string;
    /** 返回数据 */
    data: PageResponseDto<CameraResponseDto>;
  };

  type MessageDtoComposePageOfUsers = {
    /** 状态代码 */
    status_code: number;
    /** 简短的状态文本; OK 或者 ERROR */
    status: string;
    /** 详细的信息 */
    message: string;
    /** 返回数据 */
    data: PageResponseDto<UserResponseDto>;
  };

  type MessageDtoComposeUserResponseDto = {
    /** 状态代码 */
    status_code: number;
    /** 简短的状态文本; OK 或者 ERROR */
    status: string;
    /** 详细的信息 */
    message: string;
    /** 返回数据 */
    data: UserResponseDto;
  };

  type MessageDtoComposeVector = {
    /** 状态代码 */
    status_code: number;
    /** 简短的状态文本; OK 或者 ERROR */
    status: string;
    /** 详细的信息 */
    message: string;
    /** 返回数据 */
    data: any[];
  };

  type PageResponseDto<T> = {
    /** 当前页码 */
    current: number;
    /** 每页条数 */
    page_size: number;
    /** 一共条数 */
    total: number;
    /** 数据列表 */
    items: T[];
  };

  type RoleString = 'ROLE_GUEST' | 'ROLE_ADMIN';

  type SignInDto = {
    /** 用户名 */
    username: string;
    /** 密码 */
    password: string;
  };

  type updateCameraDetailsParams = {
    camera_id: number;
  };

  type updateCameraStatusParams = {
    camera_id: number;
  };

  type updateUserDetailsParams = {
    user_id: number;
  };

  type updateUserPasswordParams = {
    user_id: number;
  };

  type updateUserStatusParams = {
    user_id: number;
  };

  type UserCreateDto = {
    /** 用户名 */
    username: string;
    /** 密码 */
    password: string;
    /** 角色 */
    role: RoleString;
  };

  type UserResponseDto = {
    /** user_id */
    user_id: number;
    /** 用户名 */
    username: string;
    /** 头像 */
    avatar: string;
    /** 角色 */
    role: RoleString;
    /** 状态 */
    status: number;
    /** 创建时间 */
    create_time: number;
    /** 更新时间 */
    update_time: number;
    /** 删除时间 */
    delete_time: number;
  };

  type UserUpdateDetailsDto = {
    /** 用户名 */
    username: string;
    /** 角色 */
    role: RoleString;
    /** 状态 */
    status: number;
  };

  type UserUpdatePasswordDto = {
    /** 密码 */
    password: string;
  };

  type UserUpdateStatusDto = {
    /** 状态 */
    status: number;
  };
}
